"""custom exceptions
"""


class ChunkrInvalid(BaseException):
    """a general exception for chunkr"""
